package com.ruoyi.ems.mapper;

import java.util.List;
import com.ruoyi.ems.domain.OpEnergyStrategy;

/**
 * 能源策略Mapper接口
 * 
 * @author ruoyi
 * @date 2024-08-08
 */
public interface OpEnergyStrategyMapper
{
    /**
     * 查询能源策略
     * 
     * @param id 能源策略主键
     * @return 能源策略
     */
     OpEnergyStrategy selectOpEnergyStrategyById(Long id);

    /**
     * 查询能源策略列表
     * 
     * @param opEnergyStrategy 能源策略
     * @return 能源策略集合
     */
     List<OpEnergyStrategy> selectOpEnergyStrategyList(OpEnergyStrategy opEnergyStrategy);

    /**
     * 新增能源策略
     * 
     * @param opEnergyStrategy 能源策略
     * @return 结果
     */
     int insertOpEnergyStrategy(OpEnergyStrategy opEnergyStrategy);

    /**
     * 修改能源策略
     * 
     * @param opEnergyStrategy 能源策略
     * @return 结果
     */
     int updateOpEnergyStrategy(OpEnergyStrategy opEnergyStrategy);

    /**
     * 删除能源策略
     * 
     * @param id 能源策略主键
     * @return 结果
     */
     int deleteOpEnergyStrategyById(Long id);

    /**
     * 批量删除能源策略
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteOpEnergyStrategyByIds(Long[] ids);
}
